==> dojo-1.8.1-javadoc.jar: dojo/cldr/nls/nb/islamic.js.uncompressed.js <==
define(
"dojo/cldr/nls/nb/islamic", //begin v1.x content
{
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormat-long": "d. MMMM y G",
	"dateFormat-medium": "d. MMM y G",
	"dateFormat-short": "d.M y G",
	"dateFormatItem-d": "d.",
	"dateFormatItem-Ed": "E d.",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-M": "L",
	"dateFormatItem-Md": "d.M.",
	"dateFormatItem-MEd": "E d.M",
	"dateFormatItem-MMdd": "dd.MM",
	"dateFormatItem-MMM": "LLL",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MMMEd": "E d. MMM",
	"dateFormatItem-ms": "mm.ss",
	"dateFormatItem-yyMM": "MM.y G",
	"dateFormatItem-yyMMM": "MMM y G",
	"dateFormatItem-yyQ": "Q y G",
	"dateFormatItem-yyQQQQ": "QQQQ y G",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-yyyyM": "M y G",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormatItem-yyyyQ": "Q y G",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"days-standAlone-abbr": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dayPeriods-format-abbr-am": "a.m.",
	"dayPeriods-format-abbr-pm": "p.m.",
	"dayPeriods-format-narrow-am": "a",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormatItem-yM": "M y",
	"dateFormatItem-yMd": "d.M.yyyy",
	"dateFormatItem-yMEd": "E d.M.yyyy",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yMMMd": "d. MMM y",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"dateFormatItem-yQ": "Q yyyy",
	"dateFormatItem-yQQQ": "QQQ y",
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"dateTimeFormat-full": "{0} {1}",
	"dateTimeFormat-long": "{0} {1}",
	"dateTimeFormat-medium": "{0} {1}",
	"dateTimeFormat-short": "{0} {1}"
}
//end v1.x content
);

==> dojo-1.8.3-javadoc.jar: dojo/cldr/nls/nb/islamic.js.uncompressed.js <==
define(
"dojo/cldr/nls/nb/islamic", //begin v1.x content
{
	"dateFormatItem-yM": "M y",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-yQ": "Q yyyy",
	"dateFormatItem-MMMEd": "E d. MMM",
	"dateTimeFormat-full": "{0} {1}",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-MMdd": "dd.MM",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormat-short": "{0} {1}",
	"dateTimeFormat-medium": "{0} {1}",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"timeFormat-full": "'kl'. HH:mm:ss zzzz",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-Ed": "E d.",
	"dateFormatItem-yMMM": "MMM y",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormatItem-yyMM": "MM.y G",
	"dateFormat-medium": "d. MMM y G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormatItem-yyMMM": "MMM y G",
	"dateFormatItem-yyQQQQ": "QQQQ y G",
	"dateFormatItem-yMd": "d.M.yyyy",
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-ms": "mm.ss",
	"dayPeriods-format-narrow-am": "a",
	"dateTimeFormat-long": "{0} {1}",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-yyQ": "Q y G",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"dateFormatItem-M": "L",
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-MEd": "E d.M",
	"days-standAlone-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormatItem-hm": "h:mm a",
	"days-standAlone-abbr": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dayPeriods-format-abbr-pm": "p.m.",
	"dateFormat-short": "d.M y G",
	"dateFormatItem-yyyyM": "M y G",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormatItem-Md": "d.M.",
	"dateFormatItem-yyyyQ": "Q y G",
	"dateFormatItem-yMEd": "E d.MM.y",
	"dayPeriods-format-abbr-am": "a.m.",
	"days-format-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-d": "d.",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	]
}
//end v1.x content
);
